@@ -86,7 +86,7 @@
 #define KIOCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOCORE_NO_DEPRECATED
-#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54500
+#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54800
 #endif
 #ifdef KIOCORE_NO_DEPRECATED_WARNINGS
 #  define KIOCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOCORE_DEPRECATED_WARNINGS_SINCE KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x54500
+#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x54800
 #  endif
 #endif
 
@@ -223,9 +223,16 @@
 #else
 #  define KIOCORE_DEPRECATED_VERSION_5_69(text)
 #endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x54800
+#  define KIOCORE_DEPRECATED_VERSION_5_72(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_72(text)
+#endif
 #define KIOCORE_DEPRECATED_VERSION_3(minor, text)      KIOCORE_DEPRECATED_VERSION_3_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_4(minor, text)      KIOCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_5(minor, text)      KIOCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION(major, minor, text) KIOCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define KIOCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KIOCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* KIOCORE_EXPORT_H */
